﻿------------------------------------------------------------------------------------------
--Config UI-------------------------------------------------------------------------------
------------------------------------------------------------------------------------------
local SN, L, F, T, M, _ = unpack(select(2,...))
local LSM = LibStub("LibSharedMedia-3.0")

local AceConfig = LibStub("AceConfig-3.0")
local AceConfigDialog = LibStub("AceConfigDialog-3.0")
local AceDB = LibStub("AceDB-3.0")
local AceDBOptions = LibStub("AceDBOptions-3.0")
local AceConfigRegistry = LibStub("AceConfigRegistry-3.0")
local LibDualSpec = LibStub('LibDualSpec-1.0')

local selectedSpell

local function profileUpdate()
	db = SN.data.profile
end

local function profileChange()
	local temp = SN.data.profile.frames
	local frames = { F.powermover, F.classpower, F.cooldowns, F.dispel }

	for i, frame in pairs(frames) do
		if frame then
			frame:ClearAllPoints()
		end
	end

	if (IsAddOnLoaded("ElvUI")) then
		F.cooldowns:SetPoint(unpack(temp.elvcooldowns))
		F.debuffs:SetPoint(unpack(temp.elvdebuffs))
	else
		F.cooldowns:SetPoint(unpack(temp.cooldowns))
		F.debuffs:SetPoint(unpack(temp.debuffs))
	end
	if not F.classpower then
		F.classpower:SetPoint(unpack(temp.classpower))
	end
	if not F.dispel then
		F.dispel:SetPoint(unpack(temp.dispel))
	end
end

function SN:Initialize()
	local db = AceDB:New("SNDB", SN.DB)
	SN.data = db
	LibDualSpec:EnhanceDatabase(SN.data, "SN")
	SN.data.profile.classSelect.default = SN.playerClass
	SN:SetupConfig()
	SN:LoadConfig()
	
	
end

SN.TexCoords = {.08, .92, .08, .92}

function SN:LoadConfig()
	AceConfig:RegisterOptionsTable("SN", SN.options, nil)
	SN.options.args.profile = AceDBOptions:GetOptionsTable(SN.data)
		
	SN.optionsFrames = {}
	SN.optionsFrames.general = AceConfigDialog:AddToBlizOptions("SN", "Serenity Now", nil, "general")
	SN.optionsFrames.profile = AceConfigDialog:AddToBlizOptions("SN", "Profiles", "Serenity Now", "profile")
	
	
	LibDualSpec:EnhanceOptions(SN.options.args.profile, SN.data)

	SN.data.RegisterCallback(self, "OnProfileChanged", profileChange)
	SN.data.RegisterCallback(self, "OnProfileCopied", profileUpdate)
	SN.data.RegisterCallback(self, "OnProfileReset", profileUpdate)
end

function SN:SetupConfig()
SN.options.args = {
	general = {
		type = "group",
		name = "general",
		args = {
			descrip = {
				order = 0,
				type = "description",
				name = L["A tool to have as much of the needed information from each class\nwithin eye sight so that you can say Serenity Now!"],
			},
			h1 = {
				order = 1,
				type = "header",
				name = "",
			},
				
			lock = {
				order = 2,
				name = L["Lock Frames"],
				type = 'toggle',
				get = function()
					return SN.data.profile.frames.lock 
				end,
				set = function(key, value)
					--sn.db.profile.frames.lock = value
					SN:MoveFrames(value)
				end,
			},
			debug = {
				order = 2,
				name = L["Debug Mode"],
				type = "toggle",
				get = function()
					return SN.data.profile.debug.enable 
				end,
				set = function(key, value)
					SN.data.profile.debug.enable = value
				end,
			},
			configure = {
				order = 6,
				type = "execute",
				name = L["Apply Changes"],
				desc = L["Apply changes and reload the UI"],
				func = function()
					ReloadUI()
				end,
				order = 1,
				width = "normal",
			},
			h2 = {
				order = 7,
				type = "header",
				name = "",
			},
			cooldown = {
				order = 24,
				type = "group",
				name = L["Cooldowns"],
				args = {
					enableall = {
						name = L["Enable All CD's"],
						type = "execute",
						order = 0,
						func = function()
							for i, cd in pairs(SN.data.profile.cooldowns) do
								cd.enable = true
							end
						end,
						width = "normal",
					},
					disableall = {
						name = L["Disable All CD's"],
						type = "execute",
						order = 1,
						func = function()
							for i, cd in pairs(SN.data.profile.cooldowns) do
								cd.enable = false
							end
						end,
						width = "normal",
					},
					castannounce = {
						type = "toggle",
						name = L["Announce Casts"],
						desc = L["You will only announce if you are the Raid Leader"],
						order = 2,
						get = function()
							return SN.data.profile.cooldown.castannounce
						end,
						set = function(info, value)
							SN.data.profile.cooldown.castannounce = value
						end,
					},
					raid = {
						order = 3,
						name = L["Raid Cooldowns"],
						desc = L["Uncheck to show only your personal CD's"],
						type = "toggle",
						get = function()
							return SN.data.profile.cooldown.raid
						end,
						set = function(info, value)
							SN.data.profile.cooldown.raid = value
						end,
					},
					h3 = {
						order = 4,
						type = "header",
						name = "Dimensions",
					},
					width = {
						type = "range",
						name = L["Width of CD Bars"],
						order = 6,
						min = 50, max = 500, step = 1,
						get = function()
							return SN.data.profile.cooldown.width 
						end,
						set = function(info, value)
							SN.data.profile.cooldown.width = value
							F.cooldowns:SetWidth(value)
						end,
					},
					height = {
						type = "range",
						name = L["Height of CD Bars"],
						order = 7,
						min = 12, max = 30, step = 1,
						get = function()
							return SN.data.profile.cooldown.height 
						end,
						set = function(info, value)
							SN.data.profile.cooldown.height = value
							if F.cooldowns.bars ~= nil then
								local bars = F.cooldowns.bars
								for i in pairs(bars) do
									i:SetHeight(value)
								end
							end
						end,
					},
					h4 = {
						order = 8,
						type = "header",
						name = "Font",
					},
					font = {
						type = "select",
						dialogControl = 'LSM30_Font',
						name = L["Font"],
						order = 10,
						values = AceGUIWidgetLSMlists.font,
						get = function() return SN.data.profile.cooldown.font end,--selectedClass end,
						set = function(info, value)
							SN.data.profile.cooldown.font = value
							if F.cooldowns.bars ~= nil then
								local bars = F.cooldowns.bars
								for i in pairs(bars) do
									i:SetLabelFont(LSM:Fetch("font", value), SN.data.profile.cooldown.fontsize)
									i:SetDurationFont(LSM:Fetch("font", value), SN.data.profile.cooldown.fontsize)
								end
							end
						end,
					},
					fontsize = {
						type = "range",
						name = L["Font Size of CD Bars"],
						order = 11,
						min = 10, max = 24, step = 1,
						get = function()
							return SN.data.profile.cooldown.fontsize 
						end,
						set = function(info, value)
							SN.data.profile.cooldown.fontsize = value
							if F.cooldowns.bars ~= nil then
								local bars = F.cooldowns.bars
								for i in pairs(bars) do
									i:SetLabelFont(LSM:Fetch("font", SN.data.profile.cooldown.font), value)
									i:SetDurationFont(LSM:Fetch("font", SN.data.profile.cooldown.font), value)
								end
							end
						end,
					},
					h5 = {
						order = 12,
						type = "header",
						name = "Texture",
					},
					texture = {
						type = "select",
						dialogControl = 'LSM30_Statusbar',
						name = L["Texture"],
						order = 14,
						values = AceGUIWidgetLSMlists.statusbar,
						get = function() return SN.data.profile.cooldown.texture end,
						set = function(info, value)
							SN.data.profile.cooldown.texture = value
							if F.cooldowns.bars ~= nil then
								local bars = F.cooldowns.bars
								for i in pairs(bars) do
									i:SetTexture(LSM:Fetch("statusbar", value))
								end
							end
						end,
					},
					cooldowns = {
						order = 0,
						type = "group",
						name = L["CD List"],
						args = {
							selectClass = {
								name = L["Select Class"],
								type = "select",
								order = 0,
								values = function()
									local values = { } 
									for _, class in pairs(CLASS_SORT_ORDER) do
										class1 = strsub(class, 1, 1)
										class1 = strconcat(class1, strlower(strsub(class, 2)))
										values[class] = class1
									end
									return values
								end,
								get = function(info) return SN.data.profile.classSelect.default end,--selectedClass end,
								set = function(info, value)
									--selectedClass = value
									SN.data.profile.classSelect.default = value
								end,
							},
							h6 = {
								order = 2,
								type = "header",
								name = "",
							},
							selectSpell = {
								name = L["Select Spell"],
								type = "multiselect",
								order = 4,						
								values = function()
									local values = {}
									for _, spell in pairs(SN.data.profile.cooldowns) do
										if SN.data.profile.classSelect.default == spell.class then--selectedClass == spell.class then
											local name, _, icon = GetSpellInfo(spell.id)
											values[spell.id] = name
										end
									end
									return values
								end,
								get = function(info, spid) 
									for _, spell in pairs(SN.data.profile.cooldowns) do
										if spid == spell.id then
											return spell.enable
										end
									end
								end,
								set = function(info, spid, value)
									for _, spell in pairs(SN.data.profile.cooldowns) do
										if spid == spell.id then
											spell.enable = value
										end
									end
								end,
							},
						},
					},
				},
			},
			debuffs = {
				order = 25,
				type = "group",
				name = L["Debuffs"],
				args = {
					enable = {
						type = "toggle",
						name = L["Enable Debuff Bars"],
						order = 0,
						get = function()
							return SN.data.profile.debuffs.enable
						end,
						set = function(key, value)
							SN.data.profile.debuffs.enable = value

							if value == true then
								SN:DebuffEnable()
							elseif value == false then
								SN:DebuffDisable()
							end
						end,
					},
					h7 = {
						order = 2,
						type = "header",
						name = "Dimensions",
					},
					width = {
						type = "range",
						name = L["Width of Debuff Bars"],
						order = 4,
						min = 50, max = 500, step = 1,
						get = function()
							return SN.data.profile.debuffs.width 
						end,
						set = function(info, value)
							SN.data.profile.debuffs.width = value
							F.debuffs:SetWidth(value)
						end,
					},
					height = {
						type = "range",
						name = L["Height of Debuff Bars"],
						order = 5,
						min = 12, max = 30, step = 1,
						get = function()
							return SN.data.profile.debuffs.height 
						end,
						set = function(info, value)
							SN.data.profile.debuffs.height = value
							if F.debuffs.bars ~= nil then
								local bars = F.debuffs.bars
								for i in pairs(bars) do
									i:SetHeight(value)
								end
							end
						end,
					},
					h8 = {
						order = 6,
						type = "header",
						name = "Font",
					},
					font = {
						type = "select",
						dialogControl = 'LSM30_Font',
						name = L["Font"],
						order = 8,
						values = AceGUIWidgetLSMlists.font,
						get = function() return SN.data.profile.debuffs.font end,--selectedClass end,
						set = function(info, value)
							SN.data.profile.debuffs.font = value
							if F.debuffs.bars ~= nil then
								local bars = F.debuffs.bars
								for i in pairs(bars) do
									i:SetLabelFont(LSM:Fetch("font", value), SN.data.profile.debuffs.fontsize)
									i:SetDurationFont(LSM:Fetch("font", value), SN.data.profile.debuffs.fontsize)
								end
							end
						end,
					},
					fontsize = {
						type = "range",
						name = L["Font Size of Debuff Bars"],
						order = 9,
						min = 10, max = 24, step = 1,
						get = function()
							return SN.data.profile.debuffs.fontsize 
						end,
						set = function(info, value)
							SN.data.profile.debuffs.fontsize = value
							if F.debuffs.bars ~= nil then
								local bars = F.debuffs.bars
								for i in pairs(bars) do
									i:SetLabelFont(LSM:Fetch("font", SN.data.profile.debuffs.font), value)
									i:SetDurationFont(LSM:Fetch("font", SN.data.profile.debuffs.font), value)
								end
							end
						end,
					},
					h9 = {
						order = 12,
						type = "header",
						name = "Texture",
					},
					texture = {
						type = "select",
						dialogControl = 'LSM30_Statusbar',
						name = L["Texture"],
						order = 14,
						values = AceGUIWidgetLSMlists.statusbar,
						get = function() return SN.data.profile.debuffs.texture end,
						set = function(info, value)
							SN.data.profile.debuffs.texture = value
							if F.debuffs.bars ~= nil then
								local bars = F.debuffs.bars
								for i in pairs(bars) do
									i:SetTexture(LSM:Fetch("statusbar", value))
								end
							end
						end,
					},
				},
			},
			--powerbar = {
			--	order = 24,
			--	type = "group",
			--	name = L["Powerbar"],
			--	args = {
			--		enable = {
			--			order = 0,
			--			type = "toggle",
			--			name = L["Enable Powerbar"],
			--			get = function()
			--				return SN.data.profile.powerbar.enable
			--			end,
			--			set = function(key, value)
			--				if value == true then
			--					SN:PowerEnable()
			--				else
			--					SN:PowerDisable()
			--				end
			--				SN.data.profile.powerbar.enable = value
			--			end,
			--		},
			--		tickenable = {
			--			order = 1,
			--			name = L["Powerbar Ticks Marks"],
			--			desc = L["Tick marks on the powerbar to represent how much power you need to cast your main spell."],
			--			type = "toggle",
			--			get = function()
			--				return SN.data.profile.powerbar.tickenable
			--			end,
			--			set = function(key, value)
			--				SN.data.profile.powerbar.tickenable = value
			--				SN:SetupTicks()
			--				SN:PowebarTicks()
			--			end,
			--		},
			--		h10 = {
			--			order = 2,
			--			type = "header",
			--			name = "Dimensions",
			--		},
			--		width = {
			--			type = "range",
			--			name = L["Width of Powerbar"],
			--			order = 4,
			--			min = 50, max = 500, step = 1,
			--			get = function()
			--				return SN.data.profile.powerbar.width 
			--			end,
			--			set = function(info, value)
			--				SN.data.profile.powerbar.width = value
			--				F.powercontainer:SetWidth(value)
			--				F.power:SetWidth(value)
			--			end,
			--		},
			--		height = {
			--			type = "range",
			--			name = L["Height of Powerbar"],
			--			order = 5,
			--			min = 12, max = 30, step = 1,
			--			get = function()
			--				return SN.data.profile.powerbar.height 
			--			end,
			--			set = function(info, value)
			--				SN.data.profile.powerbar.height = value
			--				F.powercontainer:SetHeight(value)
			--				F.power:SetHeight(value)
			--			end,
			--		},
			--		h11 = {
			--			order = 6,
			--			type = "header",
			--			name = "Font",
			--		},
			--		font = {
			--			type = "select",
			--			dialogControl = 'LSM30_Font',
			--			name = L["Font"],
			--			order = 8,
			--			values = AceGUIWidgetLSMlists.font,
			--			get = function() return SN.data.profile.powerbar.font end,--selectedClass end,
			--			set = function(info, value)
			--				SN.data.profile.powerbar.font = value
			--				F.power.value:SetFont(LSM:Fetch("font", value), SN.data.profile.powerbar.fontsize, "OUTLINE")
			--			end,
			--		},
			--		fontsize = {
			--			type = "range",
			--			name = L["Font Size of Powerbar"],
			--			order = 9,
			--			min = 10, max = 24, step = 1,
			--			get = function()
			--				return SN.data.profile.powerbar.fontsize 
			--			end,
			--			set = function(info, value)
			--				SN.data.profile.powerbar.fontsize = value
			--				F.power.value:SetFont(LSM:Fetch("font", SN.data.profile.powerbar.font), value, "OUTLINE")
			--			end,
			--		},
			--		h12 = {
			--			order = 10,
			--			type = "header",
			--			name = "Texture",
			--		},
			--		texture = {
			--			type = "select",
			--			dialogControl = 'LSM30_Statusbar',
			--			name = L["Texture"],
			--			order = 12,
			--			values = AceGUIWidgetLSMlists.statusbar,
			--			get = function() return SN.data.profile.powerbar.texture end,
			--			set = function(info, value)
			--				SN.data.profile.powerbar.texture = value
			--				F.power:SetStatusBarTexture(LSM:Fetch("statusbar", value))
			--			end,
			--		},
			--	},
			--},
			classResources = {
				order = 25,
				type = "group",
				name = L["Class Power"],
				args = {
					enable = {
						order = 0,
						type = "toggle",
						name = L["Enable Class Power"],
						get = function()
							return SN.data.profile.classResources.enable
						end,
						set = function(key, value)
							if value == true then
								SN:ClassEnable()
							else
								SN:ClassDisable()
							end
							SN.data.profile.classResources.enable = value
						end,
					},
				},
			},
			dispel = {
				order = 26,
				type = "group",
				name = L["Dispel"],
				args = {
					enable = {
						type = "toggle",
						name = L["Enable Dispel System"],
						order = 0,
						get = function()
							return SN.data.profile.dispel.enable
						end,
						set = function(key, value)
							if value == true then
								F.dispel:Show()
							else
								F.dispel:Hide()
							end
							SN.data.profile.dispel.enable = value
						end,
					},
				},
			},
		},
	},
}

end

				
				--threat = {
				--	order = 26,
				--	type = "group",
				--	name = L["Threat"],
				--	args = { 
				--		threatenable = {
				--			type = "toggle",
				--			name = L["Enable Threat System"],
				--			order = 0,
				--			get = function()
				--				return SN.db.profile.threat.enable
				--			end,
				--			set = function(key, value)
				--				if value == true then
				--					SN.F.threat:Show()
				--				else
				--					SN.F.threat:Hide()
				--				end
				--				SN.db.profile.threat.enable = value
				--			end,
				--		},
				--	},
				--},
				
				
	