﻿------------------------------------------------------------------------------------------
--Frame Control Functions-----------------------------------------------------------------
------------------------------------------------------------------------------------------
local SN, L, F, T, M, _ = unpack(select(2,...))

function SN:UnlockFrame(frame)
	if frame == nil then return end

	if SN.data.profile.frames.lock and frame ~= nil then
		if frame == F.powermover then
			F.powercontainer:Hide()
		end
		if frame == F.classpower then
			if F.classpower.frame ~= nil then
				F.classpower.frame:Hide()
			end
		end
		
		frame:SetBackdrop( { bgFile   = "Interface/Tooltips/UI-Tooltip-Background",
							edgeFile = "Interface/Tooltips/UI-Tooltip-Border",
							tile     = false,
							tileSize = 0,
							edgeSize = 2,
							insets = { left = 0, right = 0, top = 0, bottom = 0 }
						} )
		frame:SetBackdropColor(.1, .1, .1, .8)
		frame:SetBackdropBorderColor(.1, .1, .1, .5)
			
		frame.value:SetText(frame.name)

		frame.d = frame:CreateTexture("ARTWORK")
		frame.d:SetHeight(16)
		frame.d:SetWidth(16)
		frame.d:SetPoint("BOTTOMRIGHT", frame, "BOTTOMRIGHT", -1, 1)
		frame.d:SetTexture(M.media.draghandle)
		frame.d:SetAlpha(.3)

		frame.tr = frame:CreateTitleRegion()
		frame.tr:SetPoint("TOPLEFT", frame, "TOPLEFT", 0, 0)
		frame.tr:SetPoint("TOPRIGHT", frame, "TOPRIGHT", 0, 0)
		frame.tr:SetHeight(21)

		frame:EnableMouse(true)
		frame:SetMovable(true)
		frame:RegisterForDrag("LeftButton")
	end
end

function SN:LockFrame(frame)
	local v = {}
	if frame == nil then return end

	if frame == F.powermover then
		v = SN.data.profile.frames.power
	elseif frame == F.classpower then
		v = SN.data.profile.frames.classpower
	end
	if frame == F.powermover then
		if SN.data.profile.powerbar.enable then
			if select(2, UnitPowerType("player")) == "RAGE" or select(2, UnitPowerType("player")) == "ENERGY" or
					select(2, UnitPowerType("player")) == "FOCUS" or 
						select(2, UnitPowerType("player")) == "RUNIC_POWER" then
						
				F.powercontainer:Show()
			end
		end
	end
	if frame == F.classpower then
		if F.classpower.frame ~= nil then
			F.classpower.frame:Show()
		end
	end
	if not SN.data.profile.frames.lock then
		frame:SetBackdrop(nil)
		frame.d:Hide()
		frame.d = nil
		frame.tr = nil
		frame.value:SetText("")
		frame:EnableMouse(false)
		frame:SetMovable(false)
		
		v[1], v[2], v[3], v[4], v[5] = frame:GetPoint()

		--sweep up
		collectgarbage("collect")

	end
end

function SN:MoveFrames(settings)
	local frames = { F.powermover, F.classpower, F.dispel }

	if settings then
		if frames[1] and F.powermover:IsShown() then
			SN:LockFrame(frames[1])
		end
		if frames[2] and F.classpower:IsShown() then
			SN:LockFrame(frames[2])
		end
		SN:LockFrame(frames[3])
		F.cooldowns:Lock(settings)
		F.debuffs:Lock(settings)

		local dp, dr, drP, dOx, dOy = F.debuffs:GetPoint()
		local cp, cr, crP, cOx, cOy = F.cooldowns:GetPoint()

		if(IsAddOnLoaded("ElvUI")) then
			SN.data.profile.frames.elvdebuffs = { dp, dr, drP, dOx, dOy }
			SN.data.profile.frames.elvcooldowns = { cp, cr, crP, cOx, cOy }
		else
			SN.data.profile.frames.debuffs = { dp, dr, drP, dOx, dOy }
			SN.data.profile.frames.cooldowns = { cp, cr, crP, cOx, cOy }
		end

		SN.data.profile.frames.lock = true
	else
		if frames[1] and F.powermover:IsShown() then
			SN:UnlockFrame(frames[1])
		end
		if frames[2] and F.classpower:IsShown() then
			SN:UnlockFrame(frames[2])
		end
		SN:UnlockFrame(frames[3])
		F.cooldowns:Lock(settings)
		F.debuffs:Lock(settings)
		
		SN.data.profile.frames.lock = false
	end
end



function ResetAnchors()
	local static = SN.DB.profile.frames
	local temp = SN.data.profile.frames
	local frames = { F.powermover, F.classpower, F.cooldowns, F.dispel }

	for i, frame in pairs(frames) do
		if frame then
			frame:ClearAllPoints()
		end
	end

	if (IsAddOnLoaded("ElvUI")) then
		F.cooldowns:SetPoint(unpack(static.elvcooldowns))
		wipe(temp.elvcooldowns)
	else
		F.cooldowns:SetPoint(unpack(static.cooldowns))
		wipe(temp.cooldowns)
	end
	if not F.classpower then
		F.classpower:SetPoint(unpack(static.classpower))
	end
	if not F.dispel then
		F.dispel:SetPoint(unpack(static.dispel))
	end
	wipe(temp.dispel)
	wipe(temp.classpower)
	ReloadUI()
end