﻿------------------------------------------------------------------------------------------
--Druid Eclipse Bar-----------------------------------------------------------------------
------------------------------------------------------------------------------------------
local SN, L, F, T, M, _ = unpack(select(2,...))

local ECLIPSE_BAR_SOLAR_BUFF_ID = ECLIPSE_BAR_SOLAR_BUFF_ID
local ECLIPSE_BAR_LUNAR_BUFF_ID = ECLIPSE_BAR_LUNAR_BUFF_ID
local SPELL_POWER_ECLIPSE = SPELL_POWER_ECLIPSE
local MOONKIN_FORM = MOONKIN_FORM
local UnitPower = UnitPower
local UnitPowerMax = UnitPowerMax
local UnitAura = UnitAura
local GetShapeshiftFormID = GetShapeshiftFormID
local GetSpecialization = GetSpecialization

function SN:SetupEclipse()
	if select(2, UnitClass("player")) ~= "DRUID" then return end
	local color = M.classResources.DRUID
	local frame = F.classpower

	local power = UnitPower("player", SPELL_POWER_ECLIPSE)
	local maxPower = UnitPowerMax("player", SPELL_POWER_ECLIPSE)

	frame.eclipse = CreateFrame("Frame", nil, frame)
	frame.eclipse:SetSize(269, 16)
	frame.eclipse:SetPoint("CENTER", frame, "CENTER", 0, 0)
	if (IsAddOnLoaded("ElvUI")) then
		SN:SNCreateBG(frame.eclipse)
	end
	frame.eclipse:SetScript("OnEvent", function(self, event, ...)
		SN:EclipseUpdate(self, event, ...)
	end)
		
	frame.eclipse.solar = CreateFrame("StatusBar", nil, frame.eclipse)
	frame.eclipse.lunar = CreateFrame("StatusBar", nil, frame.eclipse)
	
	frame.eclipse.lunar:SetSize(268, 15)
	frame.eclipse.lunar:SetPoint("LEFT", frame.eclipse)
	frame.eclipse.lunar:SetStatusBarTexture(M.media.minTex)
	frame.eclipse.lunar:GetStatusBarTexture():SetHorizTile(false)
	frame.eclipse.lunar:SetAlpha(1)
	frame.eclipse.lunar:SetMinMaxValues(-maxPower, maxPower)
	frame.eclipse.lunar:SetValue(power)
	frame.eclipse.lunar:SetStatusBarColor(unpack(color[1]))

	frame.eclipse.solar:SetSize(268, 15)
	frame.eclipse.solar:SetPoint("LEFT", frame.eclipse.lunar:GetStatusBarTexture(), "RIGHT")
	frame.eclipse.solar:SetStatusBarTexture(M.media.minTex)
	frame.eclipse.solar:GetStatusBarTexture():SetHorizTile(false)
	frame.eclipse.solar:SetAlpha(1)
	frame.eclipse.solar:SetMinMaxValues(-maxPower, maxPower)
	frame.eclipse.solar:SetValue(power * -1)
	frame.eclipse.solar:SetStatusBarColor(unpack(color[2]))
	
	frame.eclipse.value = frame.eclipse.lunar:CreateFontString(nil, 'OVERLAY')
	frame.eclipse.value:SetFont(M.media.font, 18, "OUTLINE")
	frame.eclipse.value:SetPoint("CENTER", frame.eclipse.lunar:GetStatusBarTexture(), "RIGHT")
	
	local direction = GetEclipseDirection()
	if direction == "sun" then
		frame.eclipse.value:SetText("   >")
		frame.eclipse.value:SetTextColor(.2,.2,1,1)
	elseif direction == "moon" then
		frame.eclipse.value:SetText("<")
		frame.eclipse.value:SetTextColor(1,1,.3, 1)
	else
		frame.eclipse.value:SetText("")
	end

	frame.eclipse:RegisterEvent("ECLIPSE_DIRECTION_CHANGE")
	frame.eclipse:RegisterEvent("PLAYER_TALENT_UPDATE")
	frame.eclipse:RegisterEvent("UNIT_AURA")
	frame.eclipse:RegisterEvent("UNIT_POWER")
	frame.eclipse:RegisterEvent("UPDATE_SHAPESHIFT_FORM")
	frame.eclipse:RegisterEvent("PLAYER_ALIVE")
end

function SN:EclipseUpdate(self, event, ...)
	
	if event == "ECLIPSE_DIRECTION_CHANGE" then
		local direction = GetEclipseDirection()
		if direction == "sun" then
			self.value:SetText("   >")
			self.value:SetTextColor(.2,.2,1,1)
		elseif direction == "moon" then
			self.value:SetText("<")
			self.value:SetTextColor(1,1,.3, 1)
		else
			self.value:SetText("")
		end
	end

	if event == "UNIT_POWER" then
	
		local power = UnitPower('player', SPELL_POWER_ECLIPSE)
		local maxPower = UnitPowerMax('player', SPELL_POWER_ECLIPSE)
		
		self.lunar:SetMinMaxValues(-maxPower, maxPower)
		self.lunar:SetValue(power)

		self.solar:SetMinMaxValues(-maxPower, maxPower)
		self.solar:SetValue(power * -1)
	end

	if event == "UNIT_AURA" then
		local i = 1
		local hasSolarEclipse, hasLunarEclipse
		repeat
			local _, _, _, _, _, _, _, _, _, _, spellID = UnitAura("player", i, 'HELPFUL')

			if(spellID == ECLIPSE_BAR_SOLAR_BUFF_ID) then
				hasSolarEclipse = true
			elseif(spellID == ECLIPSE_BAR_LUNAR_BUFF_ID) then
				hasLunarEclipse = true
			end

			i = i + 1
		until not spellID
	end

	if event == "UPDATE_SHAPESHIFT_FORM" or "PLAYER_TALENT_UPDATE" then
		SN:ShowEclipse(self, event, ...)
	end
	
	if event == "PLAYER_ALIVE" then
		if not SN.data.profile.classResources.enable or (GetSpecialization() ~= 1) then
			SN:EclipseDisable()
		end
	end
end

function SN:ShowEclipse(self, event, ...)
	local showBar
	local form = GetShapeshiftFormID()
	if not form then
		local ptt = GetSpecialization()
		if ptt and ptt == 1 then -- player has balance spec
			showBar = true
		end
	elseif form == MOONKIN_FORM then
		showBar = true
	end

	if showBar then
		SN:EclipseEnable()
	else
		SN:EclipseDisable()
	end
end

function SN:EclipseEnable(self)
	local frame = F.classpower
	frame.eclipse:Show()
	frame.eclipse:RegisterEvent("ECLIPSE_DIRECTION_CHANGE")
	frame.eclipse:RegisterEvent("UNIT_AURA")
	frame.eclipse:RegisterEvent("UNIT_POWER")
end

function SN:EclipseDisable(self)
	local frame = F.classpower
	frame.eclipse:UnregisterEvent("ECLIPSE_DIRECTION_CHANGE")
	frame.eclipse:UnregisterEvent("UNIT_AURA")
	frame.eclipse:UnregisterEvent("UNIT_POWER")
	frame.eclipse:Hide()
	collectgarbage("collect")
end